@@ -9,12 +9,13 @@ from abc import ABC
 from distutils.dir_util import copy_tree
 from distutils.file_util import copy_file
 from shutil import copyfile
-from typing import Any, List, Dict, Union
+from typing import Any, Dict, List, Union
 
 import numpy as np
 import yaml
-
-from baseten_scaffolding.constants import SERVING_DIR, CUSTOM, SKLEARN, PYTORCH, KERAS, HUGGINGFACE_TRANSFORMER
+from baseten_scaffolding.constants import (CUSTOM, HUGGINGFACE_TRANSFORMER,
+                                           KERAS, PYTORCH, SERVING_DIR,
+                                           SKLEARN)
 from baseten_scaffolding.model_inference import parse_requirements_file
 
 logger = logging.getLogger(__name__)
@@ -46,7 +47,6 @@ def prediction_flow(model, body):
     return response
 
 
-
 def _server_directory_name(model_framework: str):
     return f'{model_framework}_server'
 
@@ -72,14 +72,14 @@ def _server_dockerfile(model_framework: str):
 
 def _serialize_files(files, directory):
     for _file in files:
-        file_name = pathlib.PurePath(_file).name
-        new_path = pathlib.PurePath(directory, file_name)
+        new_path = pathlib.Path(directory, _file)
+        new_path.parent.mkdir(parents=True, exist_ok=True)
         copyfile(_file, new_path)
 
 
 def _serialize_dirs(dirs: List[pathlib.Path], directory: pathlib.Path):
     for _dir in dirs:
-        copy_tree(str(_dir.name), str(pathlib.Path(directory, _dir)))
+        copy_tree(str(_dir), str(pathlib.Path(directory, _dir)))
 
 
 MODEL_FOLDER = 'model'
@@ -102,7 +102,7 @@ def _files_and_dirs(glob_file_list: List[str]):
     return files, dirs
 
 
-def _load_kf_model_for_model_framework(model_framework, model_dir, build_args):
+def _load_kf_model_for_model_framework(model_framework, model_dir, build_args, config):
     from common.lib_support import ensure_kfserving_installed
     ensure_kfserving_installed()
 
@@ -115,7 +115,8 @@ def _load_kf_model_for_model_framework(model_framework, model_dir, build_args):
             name='model',
             model_class_name=build_args['MODEL_CLASS'],
             model_class_file=build_args['MODEL_CLASS_DEFINITION_FILE'],
-            model_dir=model_dir
+            model_dir=model_dir,
+            model_init_parameters=config.get('model_init_parameters', {})
         )
     elif model_framework == KERAS:
         from server.inference_model import KerasModel
@@ -126,7 +127,8 @@ def _load_kf_model_for_model_framework(model_framework, model_dir, build_args):
             name='model',
             model_class_name=build_args['MODEL_CLASS'],
             model_class_file=build_args['MODEL_CLASS_DEFINITION_FILE'],
-            model_dir=model_dir
+            model_dir=model_dir,
+            model_init_parameters=config.get('model_init_parameters', {})
         )
     elif model_framework == HUGGINGFACE_TRANSFORMER:
         from server.inference_model import TransformerModel
@@ -186,7 +188,8 @@ class AbstractModelScaffoldDefinition(ABC):
             'model_framework': self.model_framework,
             'model_type': self.model_type,
             'dockerfile': self.dockerfile,
-            'build_args': self.build_args
+            'build_args': self.build_args,
+            'model_init_parameters': self.model_init_parameters or {},
         }
 
     def server_predict(self, request: Dict):
@@ -201,7 +204,8 @@ class AbstractModelScaffoldDefinition(ABC):
         self.kf_model = _load_kf_model_for_model_framework(
             self.model_framework,
             self.scaffold_model_dir,
-            self.build_args
+            self.build_args,
+            self.config()
         )
 
 
@@ -228,6 +232,7 @@ class ReadModelScaffoldDefinition(AbstractModelScaffoldDefinition):
         self.requirements_file = self._load_requirements_file()
         self.model_type = self._load_model_type()
         self.model_framework = self._config.get('model_framework', None)
+        self.model_init_parameters = self._config.get('model_init_parameters', {})
         self.kf_model = None
         sys.path.append(str(self.scaffold_src_dir))
 
@@ -272,6 +277,7 @@ class WrittenModelScaffoldDefinition(AbstractModelScaffoldDefinition):
             path_to_scaffold: str = None,
             requirements_file: str = None,
             python_major_minor: str = None,
+            model_init_parameters: Dict = None,
     ):
         # attributes
         self.model = model
@@ -284,6 +290,7 @@ class WrittenModelScaffoldDefinition(AbstractModelScaffoldDefinition):
         self.model_type = model_type
         self.requirements_file = requirements_file
         self.python_major_minor = python_major_minor
+        self.model_init_parameters = model_init_parameters
 
         # generated attributes, order matters
         self.scaffold_dir = self._build_scaffold_directory(path_to_scaffold)
