@@ -1,14 +1,16 @@
 import ast
+import glob
+import os
 from typing import Any, List, Dict
 from pathlib import Path
 
 from baseten_scaffolding.constants import CUSTOM
 from baseten_scaffolding.definitions.base import WrittenModelScaffoldDefinition
 from baseten_scaffolding.errors import ModelFilesMissingError, ModelClassImplementationError
-from baseten_scaffolding.model_inference import parse_requirements_file
+from baseten_scaffolding.model_inference import parse_requirements_file, validate_provided_parameters_with_model
 
 
-def _validate_custom_model_definition(class_name: str, model_files: List[str]) -> str:
+def _validate_custom_model_definition(class_name: str, model_files: List[str], model_init_parameters: Dict[str, Any]) -> str:
     """Asserts that the model class is in the files and conforms to the API
 
     Args:
@@ -27,7 +29,12 @@ def _validate_custom_model_definition(class_name: str, model_files: List[str]) -
     if not model_files:
         raise ModelFilesMissingError(f'The file defining the model class `{class_name}` is missing.')
     has_supplied_model_class_definition = False
-    python_files = [f for f in model_files if f.endswith('.py')]
+    python_files = [f for f in model_files if f.endswith('.py') and os.path.isfile(f)]
+    for item in model_files:
+        # Get all python files in directories
+        if Path(item).is_dir():
+            python_files += glob.glob(f'{item}/**/*.py', recursive=True)
+    python_files = list(set(python_files))
     class_def_file = None
     for filepath in python_files:
         with open(filepath, 'r') as _file:
@@ -39,11 +46,12 @@ def _validate_custom_model_definition(class_name: str, model_files: List[str]) -
                 and stmt.name == class_name
             ]
             if model_class_definion_file:
+                validate_provided_parameters_with_model(model_class_definion_file[0], model_init_parameters)
                 cls_function_names = [stmt.name for stmt in model_class_definion_file[0].body]
                 if 'load' not in cls_function_names or 'predict' not in cls_function_names:
                     raise ModelClassImplementationError(f'The model class in {filepath} does not \
                         implement the required `load` and `predict` methods.')
-                class_def_file = Path(filepath).name
+                class_def_file = filepath
                 has_supplied_model_class_definition = True
                 break
     if not has_supplied_model_class_definition:
@@ -66,10 +74,12 @@ class CustomScaffoldDefinition(WrittenModelScaffoldDefinition):
             requirements_file: str = None,
             model_class: str = None,
             python_major_minor: str = None,
+            model_init_parameters: Dict[str, Any] = None,
     ):
         self.model_class = model_class
         super().__init__(
-            model, CUSTOM, model_files, data_files, path_to_scaffold, requirements_file, python_major_minor
+            model, CUSTOM, model_files, data_files, path_to_scaffold,
+            requirements_file, python_major_minor, model_init_parameters
         )
 
     @property
@@ -84,7 +94,9 @@ class CustomScaffoldDefinition(WrittenModelScaffoldDefinition):
 
     def serialize_model_to_directory(self, model_directory):
         if self.model_class is not None:
-            class_def_file = _validate_custom_model_definition(self.model_class, self.model_files)
+            class_def_file = _validate_custom_model_definition(
+                self.model_class, self.model_files, self.model_init_parameters
+            )
 
             self._build_args['MODEL_CLASS'] = self.model_class
             self._build_args['MODEL_CLASS_DEFINITION_FILE'] = class_def_file
